@@ -15,6 +15,7 @@ with open(BASE_DIR / 'corpora.yaml', 'r') as config_file:
 DEFAULT_OUTPUT_FOLDER = Path.cwd() / "corpora"
 
 TEI_NAMESPACE = "{http://www.tei-c.org/ns/1.0}"
+XML_NS = "{http://www.w3.org/XML/1998/namespace}"
 
 
 def progress_bar(t):
@@ -261,6 +262,10 @@ def write_json(poem_dict, filename):
     :param filename: string
         JSON filename that will be written with the poem data
     """
+    file_path = Path(filename)
+    if os.path.exists(f"{filename}.json"):
+        file_count = len(list(file_path.parent.glob(f"{file_path.stem}*.json")))
+        filename = f"{filename}{file_count + 1}"
     with open(filename + ".json", 'w', encoding='utf-8') as f:
         json.dump(poem_dict, f, ensure_ascii=False, indent=4)
 
